shapefilename                                |  var                     |  value
---------------------------------------------|--------------------------|-------
./10m_cultural/ne_10m_admin_0_countries.shp  |  New_name                |  444
./10m_cultural/ne_10m_admin_0_countries.shp  |  Deleted_name            |  0
./10m_cultural/ne_10m_admin_0_countries.shp  |  Modified_name           |  21
./10m_cultural/ne_10m_admin_0_countries.shp  |  Empty_name              |  23
./10m_cultural/ne_10m_admin_0_countries.shp  |  Same_name               |  4867
./10m_cultural/ne_10m_admin_0_countries.shp  |  Wikidataid_redirected   |  0
./10m_cultural/ne_10m_admin_0_countries.shp  |  Wikidataid_notfound     |  0
./10m_cultural/ne_10m_admin_0_countries.shp  |  Wikidataid_null         |  0
./10m_cultural/ne_10m_admin_0_countries.shp  |  Wikidataid_notnull      |  255
./10m_cultural/ne_10m_admin_0_countries.shp  |  Wikidataid_badformated  |  0
